@@ -30,6 +30,7 @@ from django.conf import settings as conf
 from django.views.generic import DetailView, ListView, CreateView
 from django.views.generic.edit import ProcessFormView
 
+from engine import expire_view_cache
 from management.commands.utils import *
 from forms import PhotoForm
 
@@ -144,6 +145,7 @@ class PhotoAddTag(LoginRequiredMixin, SuperuserRequiredMixin, ListView):
                 response_data['multiple'] = 0
                 response_data['html'] = render_to_string('rgallery/_listags.html',
                                         {'record': photo.tags.all()})
+            expire_view_cache("app_gallery-gallery")
             return HttpResponse(json.dumps(response_data), content_type="application/json")
 
 
@@ -174,6 +176,7 @@ class PhotoAdd(LoginRequiredMixin, SuperuserRequiredMixin, CreateView):
                                                                       0,
                                                                       0)
 
+        expire_view_cache("app_gallery-gallery")
         return HttpResponseRedirect(self.get_success_url())
 
 
@@ -199,6 +202,7 @@ class PhotoDelete(LoginRequiredMixin, SuperuserRequiredMixin, ListView):
                 photo.delete()
                 response_data['pk'] = pk
                 response_data['multiple'] = 0
+            expire_view_cache("app_gallery-gallery")
             return HttpResponse(json.dumps(response_data), content_type="application/json")
 
 
@@ -255,7 +259,10 @@ class PhotoChangeStatus(LoginRequiredMixin, SuperuserRequiredMixin, ListView):
                 response_data['pk'] = pk
                 response_data['status'] = photo.status
                 response_data['multiple'] = 0
+            expire_view_cache("app_gallery-gallery")
             return HttpResponse(json.dumps(response_data), content_type="application/json")
+
+
 class PhotoGetVideo(LoginRequiredMixin, ListView):
 
     model = mymodels.Photo
